Statistical comparisons of 6 different functional forms of distance decay: power-law, Gaussian, exponential, Weibull, Cauchy, and Box-Cox
dd_compare_models(city = "nyc", from = TRUE, mi = FALSE, plot = FALSE)
| city | City for which models are to be compared |
|---|---|
| from | Plot covariance or MI values for trips from each
station. If |
| mi | If |
| plot | = TRUE allows visual inspection of individual station results |
a list of data frames, one for each model, containg data frame with rows for each station and columns of [SS, k, b, AIC], where k is the width parameter of the model, and b is the shape parameter (which does not apply to power-law, Gaussian or Cauchy models).