Load pre-calculated trip matrix for a given city

dd_get_tripmat(city)

Arguments

city

City for which trip matrix is to be extracted

Value

Square matrix of numbers of trips between all stations for nominated city.

Note

The directory from which trip matrices are loaded can be retrieveed with dd_get_data_dir, and set with dd_set_data_dir.