Calculate station-to-station covariance matrix for a given city. Upper
diagonal of matrix is between all trips from i and j, so
dd_cov()[i, j] holds the covariance between all trips from
station i to all other stations and from station j to
all other stations. Analogously, the lower diagonal (dd_cov()[j, i])
holds covariances between all trips to i and j.
dd_cov(city, lower = 0, upper = 1, osm = TRUE)
| city | City for which covariance matrix is to be extracted |
|---|---|
| lower | Lower limit (0-1) for distance cutoff used to calculate covariances (see details) |
| upper | Upper limit (0-1) for distance cutoff used to calculate covariances (see details) |
| osm | If |
The directory from which trip matrices are loaded can be retrieveed
with dd_get_data_dir, and set with dd_set_data_dir. Covariances
can be calculated between stations lying within a defined distance range
using the lower and upper parameters. For example, to calculate
covariances only using the nearest half of all stations, set upper =
0.5.