dd_decay_fns
dd_decay_fns(city, from = TRUE)
| city | City for which decay parameters are to be calculated |
|---|---|
| from | Plot covariance or MI values for trips from each
station. If |
A data.frame of statistics for both straight-line distances
(_str) and OpenStreetMap network distances (_osm) for the
exponential decay function, exp (-(d / k) ^ b), of:
k, the width of the exponential;
b, the exponent; and
ss, a standardised sum of sqaured residuals of the model fit
k-values quantifying the widths of exponential fits to the decay functions.