Load pre-calculated distance matrix for a given city
dd_get_distmat(city, osm = TRUE)
| city | City for which distance matrix is to be extracted |
|---|---|
| osm | If |
Square matrix of distances between all stations for nominated city.
The directory from which distance matrices are loaded can be retrieveed with dd_get_data_dir, and set with dd_set_data_dir.