Load pre-calculated trip matrix for a given city
dd_get_tripmat(city)
| city | City for which trip matrix is to be extracted |
|---|
Square matrix of numbers of trips between all stations for nominated city.
The directory from which trip matrices are loaded can be retrieveed with dd_get_data_dir, and set with dd_set_data_dir.